@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2005 Jean-Yves Lefort <jylefort@brutele.be>
+ * Copyright © 2005 Jean-Yves Lefort <jylefort@brutele.be>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -109,7 +109,7 @@ ephy_actions_extension_detach_tab (EphyExtension *extension,
 		 		   EphyTab *tab);
 
 static const GtkActionEntry edit_entries[] = {
-	{ "EphyActionsExtensionEditActions", NULL, N_("_Actions"), NULL,
+	{ "EphyActionsExtensionEditActions", NULL, N_("Actio_ns"), NULL,
 	  N_("Customize actions"),
 	  G_CALLBACK (ephy_actions_extension_edit_actions_cb) }
 };
@@ -117,7 +117,7 @@ static const GtkActionEntry edit_entries[] = {
 GType
 ephy_actions_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo info = {
+	const GTypeInfo info = {
 		sizeof (EphyActionsExtensionClass),
 		NULL,
 		NULL,
@@ -128,7 +128,7 @@ ephy_actions_extension_register_type (GTypeModule *module)
 		0,
 		(GInstanceInitFunc) ephy_actions_extension_init
 	};
-	static const GInterfaceInfo extension_info = {
+	const GInterfaceInfo extension_info = {
 		(GInterfaceInitFunc) ephy_actions_extension_iface_init,
 		NULL,
 		NULL
@@ -463,7 +463,7 @@ ephy_actions_extension_run_action_on_embed_property (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
-	ephy_embed_event_get_property (event, property_name, &value);
+	value = ephy_embed_event_get_property (event, property_name);
 	ephy_actions_extension_run_action (action, window,
 					   g_value_get_string (value));
 }
