@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2002 Ricardo Fernández Pascual
+ *  Copyright © 2002 Ricardo Fernández Pascual
  *  Copright  (C) 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
  *
  *  This file is based on work of Daniel Erat for galeon 1.
  *
- *  $Id: ephy-gesture.c,v 1.10 2006/04/10 20:29:57 chpe Exp $
+ *  $Id: ephy-gesture.c 1376 2006-09-13 19:01:42Z chpe $
  */
 
 #include "config.h"
@@ -86,7 +86,7 @@ ephy_gesture_get_type (void)
 GType
 ephy_gesture_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyGestureClass),
 		NULL, /* base_init */
